#define HAVE_STRUCT_SOCKADDR_SA_LEN 0

/* Defined if system has POSIX ACL support. */
#define HAVE_POSIX_ACL 1
/* Defined if acl/libacl.h exists */
#define HAVE_ACL_LIBACL_H 1
/* Defined if sys/acl.h exists */
#define HAVE_SYS_ACL_H 1

#define KDE_INSTALL_FULL_LIBEXECDIR_KF "/usr/libexec/kf6"

#define KDE_INSTALL_FULL_KIO_PLUGINDIR "/usr/lib64/qt6/plugins/kf6/kio/"

#define KIO_ASSERT_WORKER_STATES 0
